# -*- coding: utf-8 -*-
__version__ = '0.1.0'


import requests


class ECB:

    def __init__(
            self,
            api_key=None):
        """
        ECB

        Create a new instance of the ECB API

        Args:
            api_key (str): The API Key for authentication

        """
        self.api_key = api_key
        self.base_url = " https://www.play-cricket.com/api/v2/"

    def _get_api_content(self,
                         api_name=None,
                         **kwargs):
        """
        _get_api_content

        Return the content from the API as a dict

        Args:
            api_name (str): The Name of the API (clubs, team, etc)
            **kwargs: Further arguments to be passed as a parameter
        """
        url = self.base_url + "/" + api_name + ".json"
        params = {"api_token": self.api_key}
        for k, v in kwargs.items():
            params.update({k: v})
        req = requests.get(url, params=params)
        status = req.status_code
        if status == 200:
            data = req.json()
        else:
            data = {}

        return {"status": status, "data": data}

    def get_club_data(self, club_id=None):
        data = self._get_api_content("clubs")
        return data



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pyecb']

package_data = \
{'': ['*']}

install_requires = \
['flake8>=4.0.1,<5.0.0',
 'mkdocs-material>=8.2.11,<9.0.0',
 'mkdocs>=1.3.0,<2.0.0',
 'mkdocstrings>=0.18.1,<0.19.0',
 'mock>=4.0.3,<5.0.0',
 'poetry-dynamic-versioning>=0.14.1,<0.15.0',
 'pytest-cov>=3.0.0,<4.0.0',
 'requests>=2.27.1,<3.0.0']

setup_kwargs = {
    'name': 'pyecb',
    'version': '0.0.11',
    'description': '',
    'long_description': None,
    'author': 'Matthew Macdonald-Wallace',
    'author_email': 'matt@doics.co',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
